.*: Assembler messages:
.*:560: Warning: Divide by zero.
.*:563: Warning: Divide by zero.
.*:576: Warning: Divide by zero.
.*:1541: Warning: Divide by zero.
.*:1544: Warning: Divide by zero.
.*:1557: Warning: Divide by zero.
.*:2604: Warning: Branch bge is always true
.*:2607: Warning: Branch bgeu is always true
.*:2616: Warning: Branch bgeu is always true
.*:2691: Warning: Branch ble is always true
.*:2706: Warning: Branch bleu is always true
.*:2712: Warning: Branch bleu is always true
.*:2715: Warning: Branch bleu is always true
.*:2814: Warning: Branch bgel is always true
.*:2817: Warning: Branch bgeul is always true
.*:2826: Warning: Branch bgeul is always true
.*:2901: Warning: Branch blel is always true
.*:2916: Warning: Branch bleul is always true
.*:2922: Warning: Branch bleul is always true
.*:2925: Warning: Branch bleul is always true
.*:4739: Warning: Divide by zero.
.*:4742: Warning: Divide by zero.
.*:4755: Warning: Divide by zero.
.*:5160: Warning: Divide by zero.
.*:5170: Warning: Divide by zero.
.*:5180: Warning: Divide by zero.
