.*: Assembler messages:
.*:63: Warning: Relaxed out-of-range branch into a jump
.*:65: Warning: Relaxed out-of-range branch into a jump
.*:67: Warning: Relaxed out-of-range branch into a jump
.*:69: Warning: Relaxed out-of-range branch into a jump
.*:71: Warning: Relaxed out-of-range branch into a jump
.*:73: Warning: Relaxed out-of-range branch into a jump
.*:75: Warning: Relaxed out-of-range branch into a jump
.*:77: Warning: Relaxed out-of-range branch into a jump
.*:79: Warning: Relaxed out-of-range branch into a jump
.*:81: Warning: Relaxed out-of-range branch into a jump
.*:83: Warning: Relaxed out-of-range branch into a jump
.*:85: Warning: Relaxed out-of-range branch into a jump
.*:87: Warning: Relaxed out-of-range branch into a jump
.*:89: Warning: Relaxed out-of-range branch into a jump
.*:91: Warning: Relaxed out-of-range branch into a jump
.*:93: Warning: Relaxed out-of-range branch into a jump
.*:95: Warning: Relaxed out-of-range branch into a jump
.*:97: Warning: Relaxed out-of-range branch into a jump
.*:99: Warning: Relaxed out-of-range branch into a jump
.*:101: Warning: Relaxed out-of-range branch into a jump
.*:103: Warning: Relaxed out-of-range branch into a jump
.*:105: Warning: Relaxed out-of-range branch into a jump
.*:107: Warning: Relaxed out-of-range branch into a jump
.*:109: Warning: Relaxed out-of-range branch into a jump
.*:111: Warning: Relaxed out-of-range branch into a jump
.*:113: Warning: Relaxed out-of-range branch into a jump
.*:115: Warning: Relaxed out-of-range branch into a jump
.*:117: Warning: Relaxed out-of-range branch into a jump
.*:119: Warning: Relaxed out-of-range branch into a jump
.*:121: Warning: Relaxed out-of-range branch into a jump
.*:123: Warning: Relaxed out-of-range branch into a jump
.*:125: Warning: Relaxed out-of-range branch into a jump
.*:127: Warning: Relaxed out-of-range branch into a jump
.*:129: Warning: Relaxed out-of-range branch into a jump
.*:131: Warning: Relaxed out-of-range branch into a jump
.*:133: Warning: Relaxed out-of-range branch into a jump
.*:135: Warning: Relaxed out-of-range branch into a jump
.*:137: Warning: Relaxed out-of-range branch into a jump
.*:139: Warning: Relaxed out-of-range branch into a jump
.*:141: Warning: Relaxed out-of-range branch into a jump
.*:143: Warning: Relaxed out-of-range branch into a jump
.*:145: Warning: Relaxed out-of-range branch into a jump
.*:147: Warning: Relaxed out-of-range branch into a jump
.*:149: Warning: Relaxed out-of-range branch into a jump
.*:151: Warning: Relaxed out-of-range branch into a jump
.*:153: Warning: Relaxed out-of-range branch into a jump
.*:155: Warning: Relaxed out-of-range branch into a jump
