/* The C source file generated by flex includes stdio.h before any of
   the C code in bfin-lex.l.  Make sure we include sysdep.h first, so
   that config.h can set the correct values for various things.  */
#include "sysdep.h"
#include "bfin-lex.c"
