        .section .text

        e_extlwi        2, 2, 1, 0
        e_extrwi        2, 3, 10, 5
        e_inslwi        4, 5, 4, 1 
        e_insrwi        6, 7, 2, 5
        e_rotlwi        1, 2, 10
        e_rotrwi        3, 4, 8
        e_slwi          2, 3, 31
        e_srwi          5, 1, 30
        e_clrlwi        4, 3, 29
        e_clrrwi        1, 2, 28
        e_clrlslwi      6, 7, 28, 27
