#objdump: -dr

.*:     file format .*

Disassembly of section \.text:

0000000000000000 <.*>:
   0:	5ee0bbe0 	abs	d0, d31
   4:	7ee0bbe0 	neg	d0, d31
   8:	5e207be0 	sqabs	b0, b31
   c:	7e207be0 	sqneg	b0, b31
  10:	5e607be0 	sqabs	h0, h31
  14:	7e607be0 	sqneg	h0, h31
  18:	5ea07be0 	sqabs	s0, s31
  1c:	7ea07be0 	sqneg	s0, s31
  20:	5ee07be0 	sqabs	d0, d31
  24:	7ee07be0 	sqneg	d0, d31
