.*: Assembler messages:
.*:50: Warning: Wrong size instruction in a 32-bit branch delay slot
.*:58: Warning: Wrong size instruction in a 16-bit branch delay slot
.*:64: Warning: Wrong size instruction in a 16-bit branch delay slot
.*:66: Warning: Wrong size instruction in a 16-bit branch delay slot
.*:68: Warning: Wrong size instruction in a 32-bit branch delay slot
.*:70: Warning: Wrong size instruction in a 32-bit branch delay slot
.*:82: Warning: Wrong size instruction in a 32-bit branch delay slot
.*:90: Warning: Wrong size instruction in a 32-bit branch delay slot
.*:92: Warning: Wrong size instruction in a 32-bit branch delay slot
